#ifndef GLOBALEVENTS_H
#define GLOBALEVENTS_H

enum GlobalEvent
{
    /// @cond GLOBNONE
    /// This will not be documented
    GLOBALEVENT_NONE,
    /// @endcond

    PLAYER_WEAPON_FIRE_ON,            ///< event received by PlayerController when player is allowed to fire
    PLAYER_WEAPON_FIRE_OFF,            ///< event received by PlayerController when player is not allowed to fire
    PLAYER_MOVEMENT_ON,                ///< event received by PlayerController when player is allowed to move with input
    PLAYER_MOVEMENT_OFF,            ///< event received by PlayerController when player is not allowed to move with input

    SCORE_INTERACTION_OCCURRED,

    GAME_VICTORIOUS,                ///< event received by Engine when player wins mission.
    GAME_DEFEAT,                    ///< event received by Engine when player is defeated.  Game play may or may not resume
    GAME_ABANDON,                    ///< event received by Engine when game play terminates.  Game play will not resume
    GAME_RESUME,                    ///< event received by Engine to resume game play (called when coming back from a Cutscene or in-game Page)
    GAME_PAUSE,                        ///< event received by Engine to pause gameplay
    GAME_CONTINUE,                    ///< event received by Engine to resume gameplay after failure (note that this will cause a Retry to be used)

    GUI_CUTSCENE,                    ///< event received by Engine & GUI when game must play a cutscene page
    GUI_PAGE,                        ///< event received by Engine & GUI when game must switch to a gui page (boss scanner)

    ENGINE_FREE_RESOURCES,            ///< event received by Engine when it should free the singleton ResourceManager resources
    ENGINE_TRANSITION_TO_GUI,        ///< event received by Engine when it should go to the GUI state

    ARENA_LOGIN,                    ///< event received by ArenaNGI class when Login should occur
    ARENA_LOGOUT,                    ///< event received by ArenaNGI class when Log out should occur
    ARENA_PROCESS,                    ///< event received by ArenaNGI class 1 when transmit/receive of data should occur
    ARENA_LOGIN_SUCCESS,            ///< event sent by ArenaNGI when a login is complete.
    ARENA_LOGIN_FAILED,                ///< event sent by ArenaNGI when we can't log in.
    ARENA_PROCESS_SUCCESS,            ///< event sent by ArenaNGI when a process call completes.

    NGAGE_STARTUP_CHECK,            ///< Event sent when N-Gage startup check should occur
    NGAGE_STARTUP_SUCCESS,            ///< Event sent when N-Gage startup check completes
    NGAGE_SWITCH_TO_PLAY,            ///< Event sent when our application wants to switch to the N-Gage application
    NGAGE_ENABLE_NOTIFICATIONS,        ///< Event sent when we are interested in in-game notifications (default)
    NGAGE_DISABLE_NOTIFICATIONS        ///< Event sent when we want to suppress in-game notifications.

};

#endif // GLOBALEVENTS_H